LowPass

Struct LowPass 

pub struct LowPass { /* private fields */ }
An effect that suppresses high frequencies.

LowPass reduces the volume of frequencies above the given cutoff. This can create the impression of sound coming from far away or in another room.

Examples

let sin = SineWave::new(1.0, 440.0);
let low_pass = LowPass::new(sin.into_shared(), 200.0);

Implementations

Source

impl LowPass

pub fn new(source: SharedAudioSource, cutoff: f32) -> Self

Construct a low-pass filter.

Arguments
  • source – The source of audio for this effect.
  • cutoff – The frequency above which volume will be reduced.
pub fn set_cutoff(&mut self, cutoff: f32)

pub fn cutoff(&self) -> f32