pub struct LowPass { /* private fields */ }Expand description
An effect that suppresses high frequencies.
LowPass reduces the volume of frequencies above the given cutoff.
This can create the impression of sound coming from far away or in another room.
Examples
let sin = SineWave::new(1.0, 440.0);
let low_pass = LowPass::new(sin.into_shared(), 200.0);Implementations